summaryrefslogtreecommitdiffstats
path: root/conduits/docconduit
diff options
context:
space:
mode:
Diffstat (limited to 'conduits/docconduit')
-rw-r--r--conduits/docconduit/DOC-converter.cc22
-rw-r--r--conduits/docconduit/DOC-converter.h3
-rw-r--r--conduits/docconduit/Makefile.am2
-rw-r--r--conduits/docconduit/doc-conduit.cc52
-rw-r--r--conduits/docconduit/doc-conduit.h9
-rw-r--r--conduits/docconduit/doc-conflictdialog.cc16
-rw-r--r--conduits/docconduit/doc-conflictdialog.h3
-rw-r--r--conduits/docconduit/doc-factory.cc4
-rw-r--r--conduits/docconduit/doc-factory.h10
-rw-r--r--conduits/docconduit/doc-setupdialog.ui60
-rw-r--r--conduits/docconduit/kpalmdoc_dlg.cc50
-rw-r--r--conduits/docconduit/kpalmdoc_dlg.h3
-rw-r--r--conduits/docconduit/kpalmdoc_dlgbase.ui44
13 files changed, 141 insertions, 137 deletions
diff --git a/conduits/docconduit/DOC-converter.cc b/conduits/docconduit/DOC-converter.cc
index cb097d8..06f45b7 100644
--- a/conduits/docconduit/DOC-converter.cc
+++ b/conduits/docconduit/DOC-converter.cc
@@ -79,7 +79,7 @@ int docMatchBookmark::findMatches(TQString doctext, bmkList &fBookmarks) {
#endif
while (pos >= 0 && found<to) {
- pos = doctext.find(pattern, pos);
+ pos = doctext.tqfind(pattern, pos);
#ifdef DEBUG
DEBUGKPILOT<<"Result of search: pos="<<pos<<endl;
#endif
@@ -120,8 +120,8 @@ int docRegExpBookmark::findMatches(TQString doctext, bmkList &fBookmarks)
// TODO: use the subexpressions from the regexp for the bmk name ($1..$9) (given as separate regexp)
TQString bmkText(bmkName);
for (int i=0; i<=rx.numCaptures(); ++i) {
- bmkText.tqreplace(CSL1("$%1").arg(i), rx.cap(i));
- bmkText.tqreplace(CSL1("\\%1").arg(i), rx.cap(i));
+ bmkText.tqreplace(CSL1("$%1").tqarg(i), rx.cap(i));
+ bmkText.tqreplace(CSL1("\\%1").tqarg(i), rx.cap(i));
}
fBookmarks.append(new docBookmark(bmkText.left(16), pos));
}
@@ -145,7 +145,7 @@ int docRegExpBookmark::findMatches(TQString doctext, bmkList &fBookmarks)
*********************************************************************/
-DOCConverter::DOCConverter(TQObject *parent, const char *name):TQObject(parent,name) {
+DOCConverter::DOCConverter(TQObject *tqparent, const char *name):TQObject(tqparent,name) {
FUNCTIONSETUP;
docdb=0L;
eSortBookmarks=eSortNone;
@@ -195,7 +195,7 @@ TQString DOCConverter::readText() {
TQFile docfile(txtfilename);
if (!docfile.open(IO_ReadOnly))
{
- emit logError(i18n("Unable to open text file %1 for reading.").arg(txtfilename));
+ emit logError(i18n("Unable to open text file %1 for reading.").tqarg(txtfilename));
return TQString();
}
@@ -437,7 +437,7 @@ bool DOCConverter::convertTXTtoPDB() {
#endif
if (!docdb->isOpen()) {
- emit logError(i18n("Unable to open palm doc database %1").arg(docdb->dbPathName()) );
+ emit logError(i18n("Unable to open palm doc database %1").tqarg(docdb->dbPathName()) );
return false;
}
@@ -520,7 +520,7 @@ bool DOCConverter::convertPDBtoTXT()
PilotRecord*headerRec = docdb->readRecordByIndex(0);
if (!headerRec)
{
- emit logError(i18n("Unable to read database header for database %1.").arg(docdb->dbPathName()));
+ emit logError(i18n("Unable to read database header for database %1.").tqarg(docdb->dbPathName()));
KPILOT_DELETE(docdb);
return false;
}
@@ -540,7 +540,7 @@ bool DOCConverter::convertPDBtoTXT()
TQFile docfile(txtfilename);
if (!docfile.open(IO_WriteOnly))
{
- emit logError(i18n("Unable to open output file %1.").arg(txtfilename));
+ emit logError(i18n("Unable to open output file %1.").tqarg(txtfilename));
KPILOT_DELETE(docdb);
return false;
}
@@ -555,7 +555,7 @@ bool DOCConverter::convertPDBtoTXT()
DEBUGKPILOT<<"Record "<<i<<endl;
KPILOT_DELETE(rec);
} else {
- emit logMessage(i18n("Could not read text record #%1 from Database %2").arg(i).arg(docdb->dbPathName()));
+ emit logMessage(i18n("Could not read text record #%1 from Database %2").tqarg(i).tqarg(docdb->dbPathName()));
}
}
@@ -574,7 +574,7 @@ bool DOCConverter::convertPDBtoTXT()
bmks.append(bmk);
KPILOT_DELETE(rec);
} else {
- emit logMessage(i18n("Could not read bookmark record #%1 from Database %2").arg(i).arg(docdb->dbPathName()));
+ emit logMessage(i18n("Could not read bookmark record #%1 from Database %2").tqarg(i).tqarg(docdb->dbPathName()));
}
}
// TODO: Sort the list of bookmarks according to their position
@@ -592,7 +592,7 @@ bool DOCConverter::convertPDBtoTXT()
if (!bmkfile.open(IO_WriteOnly))
{
emit logError(i18n("Unable to open file %1 for the bookmarks of %2.")
- .arg(bmkfilename).arg(docdb ->dbPathName()));
+ .tqarg(bmkfilename).tqarg(docdb ->dbPathName()));
}
else
{
diff --git a/conduits/docconduit/DOC-converter.h b/conduits/docconduit/DOC-converter.h
index 802d60f..27198cb 100644
--- a/conduits/docconduit/DOC-converter.h
+++ b/conduits/docconduit/DOC-converter.h
@@ -105,6 +105,7 @@ class docRegExpBookmark:public docMatchBookmark {
class DOCConverter:public TQObject {
Q_OBJECT
+ TQ_OBJECT
private:
PilotDatabase * docdb;
TQString txtfilename;
@@ -121,7 +122,7 @@ public:
} eSortBookmarks;
public:
- DOCConverter(TQObject *parent=0L, const char *name=0L);
+ DOCConverter(TQObject *tqparent=0L, const char *name=0L);
virtual ~ DOCConverter();
TQString readText();
diff --git a/conduits/docconduit/Makefile.am b/conduits/docconduit/Makefile.am
index ade1c66..03b83ad 100644
--- a/conduits/docconduit/Makefile.am
+++ b/conduits/docconduit/Makefile.am
@@ -19,7 +19,7 @@ bin_PROGRAMS = kpalmdoc
libpalmdoc_shared_la_SOURCES = makedoc9.cc pilotDOCHead.cc pilotDOCEntry.cc pilotDOCBookmark.cc DOC-converter.cc
conduit_doc_la_SOURCES = docconduitSettings.kcfgc doc-factory.cc doc-setup.cc doc-conduit.cc doc-setupdialog.ui doc-conflictdialog.cc
-conduit_doc_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries)
+conduit_doc_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries) $(PISOCK_LIB) $(LIB_QT) -lkdecore -lkio -lkdeui
conduit_doc_la_LIBADD = ../../lib/libkpilot.la libpalmdoc_shared.la \
$(LIB_KDEUI) $(LIB_KFILE)
diff --git a/conduits/docconduit/doc-conduit.cc b/conduits/docconduit/doc-conduit.cc
index 54f1ab4..0bce0fe 100644
--- a/conduits/docconduit/doc-conduit.cc
+++ b/conduits/docconduit/doc-conduit.cc
@@ -163,7 +163,7 @@ bool DOCConduit::pcTextChanged(TQString txtfn)
KMD5 docmd5;
TQFile txtfile(txtfn);
if (txtfile.open(IO_ReadOnly)){
- docmd5.update(txtfile);
+ docmd5.update(*TQT_TQIODEVICE(&txtfile));
TQString thisDigest(docmd5.hexDigest() /* .data() */);
#ifdef DEBUG
DEBUGKPILOT<<"New digest is "<<thisDigest<<endl;
@@ -362,7 +362,7 @@ bool DOCConduit::doSync(docSyncInfo &sinfo)
KMD5 docmd5;
TQFile txtfile(docconverter.txtFilename());
if (txtfile.open(IO_ReadOnly)) {
- docmd5.update(txtfile);
+ docmd5.update(*TQT_TQIODEVICE(&txtfile));
TQString thisDigest(docmd5.hexDigest() /* .data() */);
DOCConduitSettings::self()->config()->writeEntry(docconverter.txtFilename(), thisDigest);
DOCConduitSettings::self()->config()->sync();
@@ -378,10 +378,10 @@ bool DOCConduit::doSync(docSyncInfo &sinfo)
if (!postSyncAction(database, sinfo, res))
emit logError(i18n("Unable to install the locally created PalmDOC %1 to the handheld.")
- .arg(TQString::tqfromLatin1(sinfo.dbinfo.name)));
+ .tqarg(TQString::tqfromLatin1(sinfo.dbinfo.name)));
if (!res)
emit logError(i18n("Conversion of PalmDOC \"%1\" failed.")
- .arg(TQString::tqfromLatin1(sinfo.dbinfo.name)));
+ .tqarg(TQString::tqfromLatin1(sinfo.dbinfo.name)));
// disconnect(&docconverter, TQT_SIGNAL(logError(const TQString &)), TQT_SIGNAL(logError(const TQString &)));
// disconnect(&docconverter, TQT_SIGNAL(logMessage(const TQString &)), TQT_SIGNAL(logMessage(const TQString &)));
// KPILOT_DELETE(database);
@@ -389,7 +389,7 @@ bool DOCConduit::doSync(docSyncInfo &sinfo)
else
{
emit logError(i18n("Unable to open or create the database %1.")
- .arg(TQString::tqfromLatin1(sinfo.dbinfo.name)));
+ .tqarg(TQString::tqfromLatin1(sinfo.dbinfo.name)));
}
return res;
}
@@ -665,7 +665,7 @@ void DOCConduit::syncDatabases() {
case eSyncDelete:
case eSyncPDAToPC:
case eSyncPCToPDA:
- emit logMessage(i18n("Synchronizing text \"%1\"").arg(sinfo.handheldDB));
+ emit logMessage(i18n("Synchronizing text \"%1\"").tqarg(sinfo.handheldDB));
if (!doSync(sinfo)) {
// The sync could not be done, so inform the user (the error message should probably issued inside doSync)
#ifdef DEBUG
@@ -716,29 +716,29 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
N N | C P H
*/
- if (TQFile::exists(sinfo.txtfilename)) sinfo.fPCStatus=eStatNew;
- else sinfo.fPCStatus=eStatDoesntExist;
- if (docdb && docdb->isOpen()) sinfo.fPalmStatus=eStatNew;
- else sinfo.fPalmStatus=eStatDoesntExist;
+ if (TQFile::exists(sinfo.txtfilename)) sinfo.fPCtqStatus=eStatNew;
+ else sinfo.fPCtqStatus=eStatDoesntExist;
+ if (docdb && docdb->isOpen()) sinfo.fPalmtqStatus=eStatNew;
+ else sinfo.fPalmtqStatus=eStatDoesntExist;
KPILOT_DELETE(docdb);
switch (eSyncDirection) {
case eSyncPDAToPC:
- if (sinfo.fPalmStatus==eStatDoesntExist)
+ if (sinfo.fPalmtqStatus==eStatDoesntExist)
sinfo.direction=eSyncDelete;
else sinfo.direction=eSyncPDAToPC;
break;
case eSyncPCToPDA:
- if (sinfo.fPCStatus==eStatDoesntExist)
+ if (sinfo.fPCtqStatus==eStatDoesntExist)
sinfo.direction=eSyncDelete;
else sinfo.direction=eSyncPCToPDA;
break;
case eSyncNone: // means actually both directions!
- if (sinfo.fPCStatus==eStatNew) {
- if (sinfo.fPalmStatus==eStatNew) sinfo.direction=eSyncConflict;
+ if (sinfo.fPCtqStatus==eStatNew) {
+ if (sinfo.fPalmtqStatus==eStatNew) sinfo.direction=eSyncConflict;
else sinfo.direction=eSyncPCToPDA;
} else {
- if (sinfo.fPalmStatus==eStatNew) sinfo.direction=eSyncPDAToPC;
+ if (sinfo.fPalmtqStatus==eStatNew) sinfo.direction=eSyncPDAToPC;
else {
sinfo.direction=eSyncNone;
#ifdef DEBUG
@@ -756,9 +756,9 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
}
// Text was included in the last sync
- if (!TQFile::exists(sinfo.txtfilename)) sinfo.fPCStatus=eStatDeleted;
+ if (!TQFile::exists(sinfo.txtfilename)) sinfo.fPCtqStatus=eStatDeleted;
else if(pcTextChanged(sinfo.txtfilename)) {
- sinfo.fPCStatus=eStatChanged;
+ sinfo.fPCtqStatus=eStatChanged;
#ifdef DEBUG
DEBUGKPILOT<<"PC side has changed!"<<endl;
#endif
@@ -769,12 +769,12 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
#endif
}
- if (!docdb || !docdb->isOpen()) sinfo.fPalmStatus=eStatDeleted;
+ if (!docdb || !docdb->isOpen()) sinfo.fPalmtqStatus=eStatDeleted;
else if (hhTextChanged(docdb)) {
#ifdef DEBUG
DEBUGKPILOT<<"Handheld side has changed!"<<endl;
#endif
- sinfo.fPalmStatus=eStatChanged;
+ sinfo.fPalmtqStatus=eStatChanged;
#ifdef DEBUG
} else {
DEBUGKPILOT<<"Handheld side has NOT changed!"<<endl;
@@ -800,7 +800,7 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
*/
- if (sinfo.fPCStatus == eStatNone && sinfo.fPalmStatus==eStatNone) {
+ if (sinfo.fPCtqStatus == eStatNone && sinfo.fPalmtqStatus==eStatNone) {
#ifdef DEBUG
DEBUGKPILOT<<"Nothing has changed, not need for a sync."<<endl;
#endif
@@ -813,12 +813,12 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
// to sync that direction
if (eSyncDirection==eSyncPCToPDA) {
- if (sinfo.fPCStatus==eStatDeleted) sinfo.direction=eSyncDelete;
+ if (sinfo.fPCtqStatus==eStatDeleted) sinfo.direction=eSyncDelete;
else sinfo.direction=eSyncPCToPDA;
return true;
}
if (eSyncDirection==eSyncPDAToPC) {
- if (sinfo.fPalmStatus==eStatDeleted) sinfo.direction=eSyncDelete;
+ if (sinfo.fPalmtqStatus==eStatDeleted) sinfo.direction=eSyncDelete;
else sinfo.direction=eSyncPDAToPC;
return true;
}
@@ -830,8 +830,8 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
// if either is deleted, and the other is not changed, delete
- if ( ((sinfo.fPCStatus==eStatDeleted) && (sinfo.fPalmStatus!=eStatChanged)) ||
- ((sinfo.fPalmStatus==eStatDeleted) && (sinfo.fPCStatus!=eStatChanged)) )
+ if ( ((sinfo.fPCtqStatus==eStatDeleted) && (sinfo.fPalmtqStatus!=eStatChanged)) ||
+ ((sinfo.fPalmtqStatus==eStatDeleted) && (sinfo.fPCtqStatus!=eStatChanged)) )
{
#ifdef DEBUG
DEBUGKPILOT<<"DB was deleted on one side and not changed on "
@@ -843,7 +843,7 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
// eStatDeleted (and both not changed) have already been treated, for all
// other values in combination with eStatNone, just copy the texts.
- if (sinfo.fPCStatus==eStatNone) {
+ if (sinfo.fPCtqStatus==eStatNone) {
#ifdef DEBUG
DEBUGKPILOT<<"PC side has changed!"<<endl;
#endif
@@ -851,7 +851,7 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
return true;
}
- if (sinfo.fPalmStatus==eStatNone) {
+ if (sinfo.fPalmtqStatus==eStatNone) {
sinfo.direction=eSyncPCToPDA;
return true;
}
diff --git a/conduits/docconduit/doc-conduit.h b/conduits/docconduit/doc-conduit.h
index f3429bb..7b50adc 100644
--- a/conduits/docconduit/doc-conduit.h
+++ b/conduits/docconduit/doc-conduit.h
@@ -41,7 +41,7 @@ typedef enum eSyncDirectionEnum {
eSyncDelete,
eSyncConflict
};
-typedef enum eTexStatus {
+typedef enum eTextqStatus {
eStatNone=0,
eStatNew=1,
eStatChanged=2,
@@ -55,6 +55,7 @@ TQString dirToString(eSyncDirectionEnum dir);
class DOCConduit:public ConduitAction {
Q_OBJECT
+ TQ_OBJECT
public:
eSyncDirectionEnum eSyncDirection;
@@ -138,14 +139,14 @@ public:
txtfilename=txtfn;
pdbfilename=pdbfn;
direction=dir;
- fPCStatus=eStatNone;
- fPalmStatus=eStatNone;
+ fPCtqStatus=eStatNone;
+ fPalmtqStatus=eStatNone;
};
~docSyncInfo(){};
TQString handheldDB, txtfilename, pdbfilename;
DBInfo dbinfo;
eSyncDirectionEnum direction;
- eTexStatus fPCStatus, fPalmStatus;
+ eTextqStatus fPCtqStatus, fPalmtqStatus;
};
diff --git a/conduits/docconduit/doc-conflictdialog.h b/conduits/docconduit/doc-conflictdialog.h
index f0c8b21..83cb8d4 100644
--- a/conduits/docconduit/doc-conflictdialog.h
+++ b/conduits/docconduit/doc-conflictdialog.h
@@ -54,9 +54,10 @@ typedef struct conflictEntry {
class ResolutionDialog : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- ResolutionDialog( TQWidget* parent=0, const TQString& caption=i18n("Resolution Dialog"), syncInfoList*sinfo=0L, KPilotLink*lnk=0L);
+ ResolutionDialog( TQWidget* tqparent=0, const TQString& caption=i18n("Resolution Dialog"), syncInfoList*sinfo=0L, KPilotLink*lnk=0L);
~ResolutionDialog();
bool hasConflicts;
diff --git a/conduits/docconduit/doc-factory.cc b/conduits/docconduit/doc-factory.cc
index cfab20f4d..47e1d40 100644
--- a/conduits/docconduit/doc-factory.cc
+++ b/conduits/docconduit/doc-factory.cc
@@ -94,7 +94,7 @@ DOCConduitFactory::~DOCConduitFactory()
}
else
{
- WARNINGKPILOT << "Couldn't cast parent to widget." << endl;
+ WARNINGKPILOT << "Couldn't cast tqparent to widget." << endl;
return 0L;
}
}
@@ -107,7 +107,7 @@ DOCConduitFactory::~DOCConduitFactory()
}
else
{
- WARNINGKPILOT << "Couldn't cast parent to KPilotLink" <<endl;
+ WARNINGKPILOT << "Couldn't cast tqparent to KPilotLink" <<endl;
return 0L;
}
}
diff --git a/conduits/docconduit/doc-factory.h b/conduits/docconduit/doc-factory.h
index 312b9de..d1e0d72 100644
--- a/conduits/docconduit/doc-factory.h
+++ b/conduits/docconduit/doc-factory.h
@@ -37,9 +37,9 @@ class KAboutData;
class DOCConduitFactory:public KLibFactory
{
-
-Q_OBJECT
-
+ Q_OBJECT
+ TQ_OBJECT
+
public:
DOCConduitFactory(TQObject * = 0L, const char * = 0L);
virtual ~ DOCConduitFactory();
@@ -55,9 +55,9 @@ public:
protected:
- virtual TQObject * createObject(TQObject * parent = 0,
+ virtual TQObject * createObject(TQObject * tqparent = 0,
const char *name = 0,
- const char *classname = "TQObject",
+ const char *classname = TQOBJECT_OBJECT_NAME_STRING,
const TQStringList & args = TQStringList());
private:
diff --git a/conduits/docconduit/doc-setupdialog.ui b/conduits/docconduit/doc-setupdialog.ui
index f9bccb8..c2fc82b 100644
--- a/conduits/docconduit/doc-setupdialog.ui
+++ b/conduits/docconduit/doc-setupdialog.ui
@@ -1,7 +1,7 @@
<!DOCTYPE UI><UI version="3.3" stdsetdef="1">
<class>DOCWidget</class>
<author>Reinhold Kainhofer</author>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>Form2</cstring>
</property>
@@ -31,11 +31,11 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QTabWidget" row="0" column="0">
+ <widget class="TQTabWidget" row="0" column="0">
<property name="name">
<cstring>tabWidget</cstring>
</property>
- <widget class="QWidget">
+ <widget class="TQWidget">
<property name="name">
<cstring>tab</cstring>
</property>
@@ -46,7 +46,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>TextLabel1</cstring>
</property>
@@ -60,7 +60,7 @@
<string>&lt;qt&gt;Enter here, or select clicking the file picker button, the name and location of the folder used to find and synchronize text files. All files with extension .txt located in this folder will be synced to Palm DOC databases in your handheld.&lt;/qt&gt;</string>
</property>
</widget>
- <widget class="QCheckBox" row="1" column="0">
+ <widget class="TQCheckBox" row="1" column="0">
<property name="name">
<cstring>fkeepPDBLocally</cstring>
</property>
@@ -82,7 +82,7 @@
<string>&lt;qt&gt;Enter here, or select clicking the file picker button, the name and location of the folder used to find and synchronize text files. All files with extension .txt located in this folder will be synced to Palm DOC databases in your handheld.&lt;/qt&gt;</string>
</property>
</widget>
- <widget class="QButtonGroup" row="2" column="0" rowspan="1" colspan="2">
+ <widget class="TQButtonGroup" row="2" column="0" rowspan="1" colspan="2">
<property name="name">
<cstring>fSyncDirection</cstring>
</property>
@@ -99,7 +99,7 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QRadioButton" row="2" column="0">
+ <widget class="TQRadioButton" row="2" column="0">
<property name="name">
<cstring>RadioButton3</cstring>
</property>
@@ -113,7 +113,7 @@
<string>&lt;qt&gt;Select this option to synchronize texts changed in your PC to Palm DOC databases in your handheld. Palm DOC databases modified in the handheld will not be converted to text files, but texts changed in the PC will be converted to the Palm DOC databases.&lt;/qt&gt;</string>
</property>
</widget>
- <widget class="QRadioButton" row="1" column="0">
+ <widget class="TQRadioButton" row="1" column="0">
<property name="name">
<cstring>RadioButton2</cstring>
</property>
@@ -124,7 +124,7 @@
<string>&lt;qt&gt;Select this option to synchronize the changes made to Palm DOC databases in your handheld to the PC text files. Palm DOC databases modified in the handheld will be converted to text files, but texts changed in the PC will not be converted to the Palm DOC databases.&lt;/qt&gt;</string>
</property>
</widget>
- <widget class="QRadioButton" row="0" column="0">
+ <widget class="TQRadioButton" row="0" column="0">
<property name="name">
<cstring>RadioButton1</cstring>
</property>
@@ -170,7 +170,7 @@
</widget>
</grid>
</widget>
- <widget class="QWidget">
+ <widget class="TQWidget">
<property name="name">
<cstring>tab</cstring>
</property>
@@ -181,7 +181,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QCheckBox" row="0" column="0" rowspan="1" colspan="3">
+ <widget class="TQCheckBox" row="0" column="0" rowspan="1" colspan="3">
<property name="name">
<cstring>fCompress</cstring>
</property>
@@ -198,7 +198,7 @@
<string>&lt;qt&gt;The Palm DOC format supports compressing the text to save memory. Check this box to enable text compression, so the resulting Palm DOC database will consume about 50% less memory than in uncompressed state. Almost all DOC readers on the Palm support compressed texts.&lt;/qt&gt;</string>
</property>
</widget>
- <widget class="QCheckBox" row="1" column="0" rowspan="1" colspan="3">
+ <widget class="TQCheckBox" row="1" column="0" rowspan="1" colspan="3">
<property name="name">
<cstring>fConvertBookmarks</cstring>
</property>
@@ -229,7 +229,7 @@
</size>
</property>
</spacer>
- <widget class="QCheckBox" row="2" column="1">
+ <widget class="TQCheckBox" row="2" column="1">
<property name="name">
<cstring>fBookmarksInline</cstring>
</property>
@@ -243,7 +243,7 @@
<string>Check this box to create bookmarks from inline tags in the text. The inline tag consist of tags in the form &lt;* bookmarktext *&gt;. The bookmark location is set using the location of the inline tag in the text, and the name is the text between the &lt;* and the *&gt;. The inline tag (&lt;*...*&gt;) will be removed from the text.</string>
</property>
</widget>
- <widget class="QLabel" row="5" column="0">
+ <widget class="TQLabel" row="5" column="0">
<property name="name">
<cstring>textLabel1</cstring>
</property>
@@ -254,7 +254,7 @@
<cstring>fEncoding</cstring>
</property>
</widget>
- <widget class="QCheckBox" row="3" column="1">
+ <widget class="TQCheckBox" row="3" column="1">
<property name="name">
<cstring>fBookmarksEndtags</cstring>
</property>
@@ -265,7 +265,7 @@
<string>Check this box to convert tags of the form &lt;bookmarkname&gt; at the end of the text to bookmarks. The text inside the tag ("bookmarkname") will be searched in the text, and whenever found, a bookmark will be set there. The endtags &lt;...&gt; will then be removed from the end of the text.</string>
</property>
</widget>
- <widget class="QCheckBox" row="4" column="1">
+ <widget class="TQCheckBox" row="4" column="1">
<property name="name">
<cstring>fBookmarksBmk</cstring>
</property>
@@ -276,14 +276,14 @@
<string>&lt;qt&gt;Check this box to use regular expressions in a file to search the text for bookmarks. The file should have the same name as the text file, but should end in .bmk instead of .txt (for instance, the regular expression file for textname.txt should be textname.bmk). See the documentation for a description of the format of the bmk file.&lt;/qt&gt;</string>
</property>
</widget>
- <widget class="QComboBox" row="5" column="1">
+ <widget class="TQComboBox" row="5" column="1">
<property name="name">
<cstring>fEncoding</cstring>
</property>
</widget>
</grid>
</widget>
- <widget class="QWidget">
+ <widget class="TQWidget">
<property name="name">
<cstring>tab</cstring>
</property>
@@ -311,7 +311,7 @@
</size>
</property>
</spacer>
- <widget class="QCheckBox" row="1" column="0">
+ <widget class="TQCheckBox" row="1" column="0">
<property name="name">
<cstring>fNoConversionOfBmksOnly</cstring>
</property>
@@ -322,7 +322,7 @@
<string>&lt;qt&gt;Check this box to avoid syncing the text on the handheld to the PC if you only changed the bookmarks on the handheld (but not the text).&lt;/qt&gt;</string>
</property>
</widget>
- <widget class="QButtonGroup" row="0" column="0">
+ <widget class="TQButtonGroup" row="0" column="0">
<property name="name">
<cstring>fPCBookmarks</cstring>
</property>
@@ -333,7 +333,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QRadioButton" row="0" column="0">
+ <widget class="TQRadioButton" row="0" column="0">
<property name="name">
<cstring>radioButton8</cstring>
</property>
@@ -347,7 +347,7 @@
<string>&lt;qt&gt;Check this box to avoid converting Palm DOC bookmarks to inline tags or to a bookmark file.&lt;/qt&gt;</string>
</property>
</widget>
- <widget class="QRadioButton" row="1" column="0">
+ <widget class="TQRadioButton" row="1" column="0">
<property name="name">
<cstring>radioButton11</cstring>
</property>
@@ -364,7 +364,7 @@
<string>&lt;qt&gt;Check this box to convert the Palm DOC database bookmarks to a separate file, in the bmk format (see more about this format in the documentation). The resulting bookmark file shares the same filename as the resulting .txt file, but ends in .bmk instead. This approach creates a clean text file and a bookmark file.&lt;/qt&gt;</string>
</property>
</widget>
- <widget class="QRadioButton" row="2" column="0">
+ <widget class="TQRadioButton" row="2" column="0">
<property name="name">
<cstring>radioButton9</cstring>
</property>
@@ -382,7 +382,7 @@
</widget>
</grid>
</widget>
- <widget class="QWidget">
+ <widget class="TQWidget">
<property name="name">
<cstring>tab</cstring>
</property>
@@ -393,7 +393,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QButtonGroup">
+ <widget class="TQButtonGroup">
<property name="name">
<cstring>fConflictResolution</cstring>
</property>
@@ -410,7 +410,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QRadioButton" row="0" column="0">
+ <widget class="TQRadioButton" row="0" column="0">
<property name="name">
<cstring>radioButton12</cstring>
</property>
@@ -424,7 +424,7 @@
<string>&lt;qt&gt;The Palm DOC conduit does not feature merging the modifications when a text is changed both in the handheld and in the computer. Therefore, when conflicts appear, the choice is between working with the files out of sync, or discarding the changes in one of them. Select this option to prevent KPilot from overwriting your modifications.&lt;/qt&gt;</string>
</property>
</widget>
- <widget class="QRadioButton" row="1" column="0">
+ <widget class="TQRadioButton" row="1" column="0">
<property name="name">
<cstring>RadioButton5</cstring>
</property>
@@ -438,7 +438,7 @@
<string>&lt;qt&gt;The Palm DOC conduit does not feature merging the modifications when a text is changed both in the handheld and in the computer. Therefore, when conflicts appear, the choice is between working with the files out of sync, or discarding the changes in one of them. Select this option to make the PDA version overwrite the PC version in case of conflict.&lt;/qt&gt;</string>
</property>
</widget>
- <widget class="QRadioButton" row="2" column="0">
+ <widget class="TQRadioButton" row="2" column="0">
<property name="name">
<cstring>RadioButton4</cstring>
</property>
@@ -452,7 +452,7 @@
<string>&lt;qt&gt;The Palm DOC conduit does not feature merging the modifications when a text is changed both in the handheld and in the computer. Therefore, when conflicts appear, the choice is between working with the files out of sync, or discarding the changes in one of them. Select this option to make the PC version overwrite the PDA version in case of conflict.&lt;/qt&gt;</string>
</property>
</widget>
- <widget class="QRadioButton" row="3" column="0">
+ <widget class="TQRadioButton" row="3" column="0">
<property name="name">
<cstring>RadioButton7</cstring>
</property>
@@ -471,7 +471,7 @@
</widget>
</grid>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>fAlwaysUseResolution</cstring>
</property>
diff --git a/conduits/docconduit/kpalmdoc_dlg.cc b/conduits/docconduit/kpalmdoc_dlg.cc
index f73e392..0958c17 100644
--- a/conduits/docconduit/kpalmdoc_dlg.cc
+++ b/conduits/docconduit/kpalmdoc_dlg.cc
@@ -54,8 +54,8 @@
#include "kpalmdocSettings.h"
-ConverterDlg::ConverterDlg( TQWidget *parent, const TQString& caption)
- : KDialogBase( parent, "converterdialog", false, caption, KDialogBase::Close|KDialogBase::Help|KDialogBase::User1,
+ConverterDlg::ConverterDlg( TQWidget *tqparent, const TQString& caption)
+ : KDialogBase( tqparent, "converterdialog", false, caption, KDialogBase::Close|KDialogBase::Help|KDialogBase::User1,
KDialogBase::Close, true, i18n("&About"))
{
TQWidget *page = makeHBoxMainWidget();
@@ -78,7 +78,7 @@ ConverterDlg::ConverterDlg( TQWidget *parent, const TQString& caption)
ConverterDlg::~ConverterDlg()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
void ConverterDlg::writeSettings()
{
@@ -175,8 +175,8 @@ void ConverterDlg::slotToText()
int res=KMessageBox::questionYesNo(this,
i18n("<qt>You selected to sync folders, "
"but gave a filename instead (<em>%1</em>)."
- "<br>Use folder <em>%2</em> instead?</qt>").arg(pdburl)
- .arg(pdbinfo.dirPath(true)), TQString::null, i18n("Use Folder"), KStdGuiItem::cancel());
+ "<br>Use folder <em>%2</em> instead?</qt>").tqarg(pdburl)
+ .tqarg(pdbinfo.dirPath(true)), TQString(), i18n("Use Folder"), KStdGuiItem::cancel());
if (res==KMessageBox::Yes)
{
pdburl=pdbinfo.dirPath(true);
@@ -191,7 +191,7 @@ void ConverterDlg::slotToText()
KMessageBox::sorry(this,
i18n("<qt>The folder <em>%1</em> for "
"the handheld database files is not a valid "
- "folder.</qt>").arg(pdburl));
+ "folder.</qt>").tqarg(pdburl));
return;
}
@@ -200,7 +200,7 @@ void ConverterDlg::slotToText()
KMessageBox::sorry(this,
i18n("<qt>The folder <em>%1</em> for "
"the handheld database files is not a "
- "valid directory.</qt>").arg(pdburl));
+ "valid directory.</qt>").tqarg(pdburl));
return;
}
@@ -211,8 +211,8 @@ void ConverterDlg::slotToText()
int res=KMessageBox::questionYesNo(this,
i18n("<qt>You selected to sync folders, "
"but gave a filename instead (<em>%1</em>)."
- "<br>Use folder <em>%2</em> instead?</qt>").arg(txturl)
- .arg(txtinfo.dirPath(true)), TQString::null, i18n("Use Folder"), KStdGuiItem::cancel());
+ "<br>Use folder <em>%2</em> instead?</qt>").tqarg(txturl)
+ .tqarg(txtinfo.dirPath(true)), TQString(), i18n("Use Folder"), KStdGuiItem::cancel());
if (res==KMessageBox::Yes) {
txturl=txtinfo.dirPath(true);
txtinfo.setFile(txturl);
@@ -227,7 +227,7 @@ void ConverterDlg::slotToText()
if (!txtinfo.isDir()) {
KMessageBox::sorry(this,
i18n("<qt>The folder <em>%1</em> for "
- "the text files could not be created.</qt>").arg(txturl));
+ "the text files could not be created.</qt>").tqarg(txturl));
return;
}
@@ -265,7 +265,7 @@ void ConverterDlg::slotToText()
if (!pdbinfo.isFile() || !pdbinfo.exists())
{
KMessageBox::sorry(this, i18n("<qt>The file <em>%1</em> does not "
- "exist.</qt>").arg(pdburl));
+ "exist.</qt>").tqarg(pdburl));
return;
}
@@ -274,13 +274,13 @@ void ConverterDlg::slotToText()
if (!txtinfo.isFile())
{
KMessageBox::sorry(this, i18n("<qt>The filename <em>%1</em> for the "
- "text is not a valid filename.</qt>").arg(txturl));
+ "text is not a valid filename.</qt>").tqarg(txturl));
return;
}*/
if (convertPDBtoTXT(pdbinfo.dirPath(true), pdbinfo.fileName(),
txtinfo.dirPath(true), txtinfo.fileName(), &conv) )
{
- KMessageBox::information(this, i18n("Conversion of file %1 successful.").arg(pdburl));
+ KMessageBox::information(this, i18n("Conversion of file %1 successful.").tqarg(pdburl));
}
}
@@ -324,8 +324,8 @@ void ConverterDlg::slotToPDB()
int res=KMessageBox::questionYesNo(this,
i18n("<qt>You selected to sync folders, "
"but gave a filename instead (<em>%1</em>)."
- "<br>Use folder <em>%2</em> instead?</qt>").arg(txturl)
- .arg(txtinfo.dirPath(true)), TQString::null, i18n("Use Folder"), KStdGuiItem::cancel());
+ "<br>Use folder <em>%2</em> instead?</qt>").tqarg(txturl)
+ .tqarg(txtinfo.dirPath(true)), TQString(), i18n("Use Folder"), KStdGuiItem::cancel());
if (res==KMessageBox::Yes)
{
txturl=txtinfo.dirPath(true);
@@ -338,7 +338,7 @@ void ConverterDlg::slotToPDB()
{
KMessageBox::sorry(this,
i18n("<qt>The folder <em>%1</em> for "
- "the text files is not a valid folder.</qt>").arg(txturl));
+ "the text files is not a valid folder.</qt>").tqarg(txturl));
return;
}
@@ -350,8 +350,8 @@ void ConverterDlg::slotToPDB()
i18n("<qt>You selected to sync folders, "
"but gave a filename instead (<em>%1</em>)."
"<br>Use folder <em>%2</em> instead?</qt>")
- .arg(pdburl)
- .arg(pdbinfo.dirPath(true)), TQString::null, i18n("Use Folder"), KStdGuiItem::cancel());
+ .tqarg(pdburl)
+ .tqarg(pdbinfo.dirPath(true)), TQString(), i18n("Use Folder"), KStdGuiItem::cancel());
if (res==KMessageBox::Yes) {
pdburl=pdbinfo.dirPath(true);
pdbinfo.setFile(pdburl);
@@ -365,7 +365,7 @@ void ConverterDlg::slotToPDB()
}
if (!pdbinfo.isDir()) {
KMessageBox::sorry(this, i18n("<qt>The folder <em>%1</em> for "
- "the PalmDOC files could not be created.</qt>").arg(pdburl));
+ "the PalmDOC files could not be created.</qt>").tqarg(pdburl));
return;
}
@@ -403,14 +403,14 @@ void ConverterDlg::slotToPDB()
if (!txtinfo.isFile() || !txtinfo.exists())
{
KMessageBox::sorry(this, i18n("<qt>The file <em>%1</em> does not "
- "exist.</qt>").arg(txturl));
+ "exist.</qt>").tqarg(txturl));
return;
}
if (convertTXTtoPDB(txtinfo.dirPath(true), txtinfo.fileName(),
pdbinfo.dirPath(true), pdbinfo.fileName(), &conv) )
{
- KMessageBox::information(this, i18n("Conversion of file %1 successful.").arg(txturl));
+ KMessageBox::information(this, i18n("Conversion of file %1 successful.").tqarg(txturl));
}
}
@@ -454,7 +454,7 @@ bool ConverterDlg::convertTXTtoPDB(TQString txtdir, TQString txtfile,
if (!dbfileinfo.exists() || !askOverwrite ||
(KMessageBox::Yes==KMessageBox::questionYesNo(this,
i18n("<qt>The database file <em>%1</em> already exists. Overwrite it?</qt>")
- .arg(dbfileinfo.filePath()), TQString::null, i18n("Overwrite"), KStdGuiItem::cancel() ) ))
+ .tqarg(dbfileinfo.filePath()), TQString(), i18n("Overwrite"), KStdGuiItem::cancel() ) ))
{
PilotLocalDatabase*pdbdb=new PilotLocalDatabase(pdbdir, TQFileInfo(pdbfile).baseName(), false);
if (pdbdb)
@@ -479,7 +479,7 @@ bool ConverterDlg::convertTXTtoPDB(TQString txtdir, TQString txtfile,
}
if ( !res && verbose )
{
- KMessageBox::sorry(this, i18n("<qt>Error while converting the text %1.</qt>").arg(txtfile));
+ KMessageBox::sorry(this, i18n("<qt>Error while converting the text %1.</qt>").tqarg(txtfile));
}
}
else
@@ -499,7 +499,7 @@ bool ConverterDlg::convertPDBtoTXT(TQString pdbdir, TQString pdbfile,
if (!txtfileinfo.exists() || !askOverwrite ||
(KMessageBox::Yes==KMessageBox::questionYesNo(this,
i18n("<qt>The text file <em>%1</em> already exists. Overwrite it?</qt>")
- .arg(txtfileinfo.filePath()), TQString::null, i18n("Overwrite"), KStdGuiItem::cancel() ) ))
+ .tqarg(txtfileinfo.filePath()), TQString(), i18n("Overwrite"), KStdGuiItem::cancel() ) ))
{
PilotLocalDatabase*pdbdb=new PilotLocalDatabase(pdbdir, TQFileInfo(pdbfile).baseName(), false);
if (pdbdb)
@@ -515,7 +515,7 @@ bool ConverterDlg::convertPDBtoTXT(TQString pdbdir, TQString pdbfile,
}
if ( !res && verbose )
{
- KMessageBox::sorry(this, i18n("<qt>Error while converting the text %1.</qt>").arg(pdbfile));
+ KMessageBox::sorry(this, i18n("<qt>Error while converting the text %1.</qt>").tqarg(pdbfile));
}
}
else
diff --git a/conduits/docconduit/kpalmdoc_dlg.h b/conduits/docconduit/kpalmdoc_dlg.h
index 5e9202b..6fe6e57 100644
--- a/conduits/docconduit/kpalmdoc_dlg.h
+++ b/conduits/docconduit/kpalmdoc_dlg.h
@@ -35,9 +35,10 @@ class DOCConverter;
class ConverterDlg : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- ConverterDlg( TQWidget *parent=0, const TQString& caption=0);
+ ConverterDlg( TQWidget *tqparent=0, const TQString& caption=0);
~ConverterDlg();
protected slots:
diff --git a/conduits/docconduit/kpalmdoc_dlgbase.ui b/conduits/docconduit/kpalmdoc_dlgbase.ui
index ee2bd2a..2b5b581 100644
--- a/conduits/docconduit/kpalmdoc_dlgbase.ui
+++ b/conduits/docconduit/kpalmdoc_dlgbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.3" stdsetdef="1">
<class>ConverterDlgBase</class>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>ConverterDlgBase</cstring>
</property>
@@ -16,11 +16,11 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QTabWidget" row="0" column="0">
+ <widget class="TQTabWidget" row="0" column="0">
<property name="name">
<cstring>tabWidget</cstring>
</property>
- <widget class="QWidget">
+ <widget class="TQWidget">
<property name="name">
<cstring>tab</cstring>
</property>
@@ -31,7 +31,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel" row="1" column="0">
+ <widget class="TQLabel" row="1" column="0">
<property name="name">
<cstring>fPdbLabel</cstring>
</property>
@@ -50,7 +50,7 @@
<cstring>fPDBDir</cstring>
</property>
</widget>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>fTextLabel</cstring>
</property>
@@ -69,7 +69,7 @@
<cstring>fTXTDir</cstring>
</property>
</widget>
- <widget class="QCheckBox" row="2" column="1" rowspan="1" colspan="2">
+ <widget class="TQCheckBox" row="2" column="1" rowspan="1" colspan="2">
<property name="name">
<cstring>fDirectories</cstring>
</property>
@@ -85,7 +85,7 @@
<string>Folder where copies of the handheld databases are kept. You can install them to any PalmOS handheld, and distribute these copies to other people (but beware of copyright infringement).</string>
</property>
</widget>
- <widget class="QCheckBox" row="3" column="1" rowspan="1" colspan="2">
+ <widget class="TQCheckBox" row="3" column="1" rowspan="1" colspan="2">
<property name="name">
<cstring>fAskOverwrite</cstring>
</property>
@@ -93,7 +93,7 @@
<string>&amp;Ask before overwriting files</string>
</property>
</widget>
- <widget class="QCheckBox" row="4" column="1" rowspan="1" colspan="2">
+ <widget class="TQCheckBox" row="4" column="1" rowspan="1" colspan="2">
<property name="name">
<cstring>fVerbose</cstring>
</property>
@@ -142,12 +142,12 @@
<string>Enter the name of the folder where the text files reside on the PC. All files with extension .txt will be synced to the handheld.</string>
</property>
</widget>
- <widget class="QComboBox" row="5" column="1" rowspan="1" colspan="2">
+ <widget class="TQComboBox" row="5" column="1" rowspan="1" colspan="2">
<property name="name">
<cstring>fEncoding</cstring>
</property>
</widget>
- <widget class="QLabel" row="5" column="0">
+ <widget class="TQLabel" row="5" column="0">
<property name="name">
<cstring>textLabel1</cstring>
</property>
@@ -160,7 +160,7 @@
</widget>
</grid>
</widget>
- <widget class="QWidget">
+ <widget class="TQWidget">
<property name="name">
<cstring>tab</cstring>
</property>
@@ -222,7 +222,7 @@
</size>
</property>
</spacer>
- <widget class="QCheckBox" row="2" column="1">
+ <widget class="TQCheckBox" row="2" column="1">
<property name="name">
<cstring>fBookmarksInline</cstring>
</property>
@@ -236,7 +236,7 @@
<string>When a &lt;* bookmarktext *&gt; appears somewhere in the text, a bookmark will be set at this position, and the text between the &lt;* and the *&gt; will be used as bookmark name. The &lt;*...*&gt; will be removed from the text.</string>
</property>
</widget>
- <widget class="QCheckBox" row="3" column="1">
+ <widget class="TQCheckBox" row="3" column="1">
<property name="name">
<cstring>fBookmarksEndtags</cstring>
</property>
@@ -247,7 +247,7 @@
<string>Tags of the form &lt;bookmarkname&gt; at the end of the text will be used to search the text for the pattern between the &lt; and &gt;. Whenever "bookmarkname" appears in the text, a bookmark will be set there. The endtags &lt;...&gt; will then be removed from the end of the text.</string>
</property>
</widget>
- <widget class="QCheckBox" row="0" column="0" rowspan="1" colspan="2">
+ <widget class="TQCheckBox" row="0" column="0" rowspan="1" colspan="2">
<property name="name">
<cstring>fCompress</cstring>
</property>
@@ -264,7 +264,7 @@
<string>The Palm doc format supports compressing the text to save memory. If you check this box, the text will consume about 50% less memory than in uncompressed state. Almost all DOC readers on the Palm support compressed texts.</string>
</property>
</widget>
- <widget class="QCheckBox" row="1" column="0" rowspan="1" colspan="2">
+ <widget class="TQCheckBox" row="1" column="0" rowspan="1" colspan="2">
<property name="name">
<cstring>fConvertBookmarks</cstring>
</property>
@@ -278,7 +278,7 @@
<string>Do you want to convert bookmarks? Most doc readers support bookmarks. You have to provide some information about where the bookmarks should be set and their titles. Check at least one of the bookmark types below.</string>
</property>
</widget>
- <widget class="QCheckBox" row="4" column="1">
+ <widget class="TQCheckBox" row="4" column="1">
<property name="name">
<cstring>fBookmarksBmk</cstring>
</property>
@@ -308,7 +308,7 @@
</spacer>
</grid>
</widget>
- <widget class="QWidget">
+ <widget class="TQWidget">
<property name="name">
<cstring>tab</cstring>
</property>
@@ -336,7 +336,7 @@
</size>
</property>
</spacer>
- <widget class="QButtonGroup" row="0" column="0">
+ <widget class="TQButtonGroup" row="0" column="0">
<property name="name">
<cstring>fPCBookmarks</cstring>
</property>
@@ -347,7 +347,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QRadioButton" row="1" column="0">
+ <widget class="TQRadioButton" row="1" column="0">
<property name="name">
<cstring>radioButton9</cstring>
</property>
@@ -361,7 +361,7 @@
<number>1</number>
</property>
</widget>
- <widget class="QRadioButton" row="0" column="0">
+ <widget class="TQRadioButton" row="0" column="0">
<property name="name">
<cstring>radioButton8</cstring>
</property>
@@ -375,7 +375,7 @@
<number>0</number>
</property>
</widget>
- <widget class="QRadioButton" row="2" column="0">
+ <widget class="TQRadioButton" row="2" column="0">
<property name="name">
<cstring>radioButton10</cstring>
</property>
@@ -386,7 +386,7 @@
<string>Convert as &amp;end tags</string>
</property>
</widget>
- <widget class="QRadioButton" row="3" column="0">
+ <widget class="TQRadioButton" row="3" column="0">
<property name="name">
<cstring>radioButton11</cstring>
</property>
diff --git a/conduits/docconduit/doc-conflictdialog.cc b/conduits/docconduit/doc-conflictdialog.cc
index 7b19586..5ea646b 100644
--- a/conduits/docconduit/doc-conflictdialog.cc
+++ b/conduits/docconduit/doc-conflictdialog.cc
@@ -39,8 +39,8 @@
#include <tqscrollview.h>
-ResolutionDialog::ResolutionDialog( TQWidget* parent, const TQString& caption, syncInfoList*sinfo, KPilotLink*lnk )
- : KDialogBase( parent, "resolutionDialog", true, caption, KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true), tickleTimer(0L), fHandle(lnk) {
+ResolutionDialog::ResolutionDialog( TQWidget* tqparent, const TQString& caption, syncInfoList*sinfo, KPilotLink*lnk )
+ : KDialogBase( tqparent, "resolutionDialog", true, caption, KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true), tickleTimer(0L), fHandle(lnk) {
FUNCTIONSETUP;
syncInfo=sinfo;
hasConflicts=false;
@@ -70,7 +70,7 @@ ResolutionDialog::ResolutionDialog( TQWidget* parent, const TQString& caption, s
resolutionGroupBoxLayout = new TQGridLayout( big_box, syncInfo->size(), 3 );
- resolutionGroupBoxLayout->tqsetAlignment( Qt::AlignTop );
+ resolutionGroupBoxLayout->tqsetAlignment( TQt::AlignTop );
// Invisible button group for the information buttons to use the same slot for all of them (see Dallheimer's book, page 309f)
TQButtonGroup *bgroup = new TQButtonGroup( this );
@@ -138,7 +138,7 @@ ResolutionDialog::ResolutionDialog( TQWidget* parent, const TQString& caption, s
*/
ResolutionDialog::~ResolutionDialog()
{
// no need to delete child widgets, Qt does it all for us
}
/* virtual slot */ void ResolutionDialog::slotOk() {
@@ -150,7 +150,7 @@ ResolutionDialog::~ResolutionDialog()
KDialogBase::slotOk();
}
-TQString eTexStatusToString(eTexStatus stat) {
+TQString eTexStatusToString(eTextqStatus stat) {
switch(stat) {
case eStatNone: return i18n("unchanged");
case eStatNew: return i18n("new");
@@ -168,9 +168,9 @@ void ResolutionDialog::slotInfo(int index) {
int ix=cE.index;
if (!syncInfo) return;
docSyncInfo si=(*syncInfo)[ix];
- TQString text=i18n("Status of the database %1:\n\n").arg(si.handheldDB);
- text+=i18n("Handheld: %1\n").arg(eTexStatusToString(si.fPalmStatus));
- text+=i18n("Desktop: %1\n").arg(eTexStatusToString(si.fPCStatus));
+ TQString text=i18n("tqStatus of the database %1:\n\n").tqarg(si.handheldDB);
+ text+=i18n("Handheld: %1\n").tqarg(eTexStatusToString(si.fPalmtqStatus));
+ text+=i18n("Desktop: %1\n").tqarg(eTexStatusToString(si.fPCtqStatus));
KMessageBox::information(this, text, i18n("Database information"));
}
@@ -138,7 +138,7 @@ ResolutionDialog::ResolutionDialog( TQWidget* parent, const TQString& caption, s
ResolutionDialog::~ResolutionDialog()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/* virtual slot */ void ResolutionDialog::slotOk() {